State of Maine Judicial Branch: Supreme Court Opinions

- Skip First Level Navigation
- Skip All Navigation

## Maine.gov

- Agencies |
- Online Services |
- Help |
- Search Maine.gov

Page Tools

## State of Maine Judicial Branch

# Published Opinions of the Law Court

These opinions are subject to motions for reconsideration pursuant to Rule 14(b) of the Maine Rules of Appellate Procedure, and to revision and correction before final publication. Readers are asked to notify the Reporter of Decisions of any typographical, grammatical or other formal errors by U.S. Mail to Clerk of the Law Court, 205 Newbury Street, Room 139, Portland, ME 04101-4125, or by filling out the form on the Contact Us page of this website.

The permanent, official versions of Maine Supreme Judicial Court's opinions are those published in the Atlantic Reporter (2d Series and 3d Series), which has been Maine's official reporter since 1966.

Opinions have been published online since January 1997. Decisions published online should be cited in the following style:

> Dutil v. Burns, 1997 ME 1,¶ 2, 687 A.2d 639.

##

## Citations

Maine Law Review: Uniform Maine Citations

Uniform Maine Citations, 2011 Edition, provides updated rules for the citation of Maine legal authorities, including judicial decisions, constitutional provisions, statutory and legislative materials, court rules, treatises, periodicals, and miscellaneous Maine authorities.

##

## Opinions

Opinions published online since January 2006 are in pdf format. The free Adobe Acrobat Reader is necessary to view those opinions.

## Previous years' opinions

2013 | 2009 | 2005 | 2001 | 1997
2012 | 2008 | 2004 | 2000 |
2011 | 2007 | 2003 | 1999 |
2010 | 2006 | 2002 | 1998 |

##

## This year's opinions:

June 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 74 | State of Maine v. Julia Peck | June 10, 2014
2014 ME 75 | Estate of Ruth E. O'Brien-Hamel | June 10, 2014

May 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 62 | Irving Oil Limited et al. v. ACE INA Insurance | May 1, 2014
2014 ME 63 | Friends of Congress Square Park et al. v. City of Portland | May 6, 2014
2014 ME 64 | Paula Bratton et al. v. Halsey McDonough | May 6, 2014

April 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 51 | Philip C. Tobin v. Philip N. Barter | April 1, 2014
2014 ME 52 | Mallinckrodt US LLC et al. v. Department of Environmental Protection | April 3, 2014

March 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 34 | Estate of Michael Lewis v. Concord General Mutual Insurance Company | March 4, 2014
2014 ME 35 | State of Maine v. Andrew J. Freeman | March 4, 2014
2014 ME 36 | Adoption of T.D. | March 4, 2014

February 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 12 | Robert F. Almeder et al. v. Town of Kennebunkport et al. | February 4, 2014
2014 ME 13 | Christine A. Murphy v. William E. Bartlett | February 4, 2014

January 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 1 | In re Steven L. | January 9, 2014
2014 ME 2 | Estate of Mary E. Hiller | January 9, 2014
2014 ME 3 | Lisa Lesko v. Theodore Stanislaw | January 14, 2014